@@ -3,8 +3,8 @@
 ;; Copyright 2018 Jane Street Group, LLC <opensource@janestreet.com>
 ;;           2017- Christophe Troestler
 ;; URL: https://github.com/ocaml/dune
-;; Package-Version: 20250903.1130
-;; Package-Revision: 1e54fd3f450a
+;; Package-Version: 20260120.2128
+;; Package-Revision: ccdb380ab571
 
 ;;; Commentary:
 
@@ -427,6 +427,17 @@ For customization purposes, use `dune-mode-hook'."
   (compile (format "%s build @@runtest" dune-command))
   (dune-promote))
 
+;;;###autoload
+(defun dune-find-dominating ()
+  "Find dominating dune file."
+  (interactive)
+  (if-let* ((dune-file-dir (locate-dominating-file "." "dune"))
+            (dune-file (concat dune-file-dir "dune")))
+      (progn
+        (xref-push-marker-stack)
+        (find-file dune-file))
+    (error "Found no dune file dominating %s" default-directory)))
+
 (defun dune-project-p (directory)
   "Return t if DIRECTORY is a dune project."
   (file-exists-p (expand-file-name "dune-project" directory)))
